from setuptools import setup, find_packages

setup(
    name="edoc",
    version="1.0.1",
    description=("Extract text from doc"),
    long_description=open("README.rst").read(),
    author="twfb",
    author_email="twfb@hotmail.com",
    maintainer="twfb",
    maintainer_email="twfb@hotmail.com",
    license="BSD License",
    packages=find_packages(),
    platforms=["all"],
    include_package_data=True,
    url="https://github.com/twfb/edoc",
    install_requires=["olefile"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: Implementation",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Software Development :: Libraries",
    ],
),
